@@ -58,10 +58,13 @@ class Loader(BaseLoader):
         if settings.DEBUG or key not in self.template_cache:
 
             if os.path.splitext(template_name)[1] in ('.jade',):
-                source, display_name = self.load_template_source(template_name, template_dirs)
-                source=process(source,filename=template_name,compiler=Compiler)
-                origin = make_origin(display_name, self.load_template_source, template_name, template_dirs)
-                template = get_template_from_string(source, origin, template_name)
+                try:
+                    source, display_name = self.load_template_source(template_name, template_dirs)
+                    source=process(source,filename=template_name,compiler=Compiler)
+                    origin = make_origin(display_name, self.load_template_source, template_name, template_dirs)
+                    template = get_template_from_string(source, origin, template_name)
+                except NotImplementedError:
+                    template, origin = self.find_template(template_name, template_dirs)
             else:
                 template, origin = self.find_template(template_name, template_dirs)
             if not hasattr(template, 'render'):
